@@ -12,6 +12,11 @@ from datetime import (
     timedelta,
 )
 
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
+
 
 class TahrirDatabase(object):
     """
@@ -324,6 +329,28 @@ class TahrirDatabase(object):
             return email
         return False
 
+    @autocommit
+    def note_login(self, person_email=None, id=None, nickname=None):
+        """ Make a note that a person has logged in. """
+
+        person = self.get_person(person_email, id, nickname)
+
+        # If this is the first time they have ever logged in, optionally
+        # publish a notification about the event.
+        if not person.last_login and self.notification_callback:
+            self.notification_callback(
+                topic='person.login.first',
+                msg=dict(
+                    user=dict(
+                        username=person.nickname,
+                        badges_user_id=person.id,
+                    )
+                )
+            )
+
+        # Finally, update the field.
+        person.last_login = datetime.utcnow()
+
     def issuer_exists(self, origin, name):
         """
         Check to see if an issuer with this ID is in the database
@@ -617,8 +644,8 @@ class TahrirDatabase(object):
             return
 
         # Otherwise, take our calculations and commit them to the db.
-        for person, data in leaderboard.items():
-            person.rank = data['rank']
+        for _person, data in leaderboard.items():
+            _person.rank = data['rank']
 
         self.session.flush()
 
@@ -674,7 +701,7 @@ class TahrirDatabase(object):
         #     'rank': <their global rank>
         #   }
         # }
-        user_to_rank = dict(
+        user_to_rank = OrderedDict(
             [
                 (
                     data[0],
